@@ -3,7 +3,7 @@
 import itertools
 import os
 from collections import namedtuple
-from datetime import datetime, timedelta
+from datetime import timedelta
 
 import nbformat
 from tornado.web import HTTPError
@@ -18,13 +18,13 @@ import jupytext
 
 from .config import (
     JUPYTEXT_CONFIG_FILES,
+    PYPROJECT_FILE,
     JupytextConfiguration,
     JupytextConfigurationError,
     find_global_jupytext_configuration_file,
     load_jupytext_configuration_file,
+    notebook_formats,
     preferred_format,
-    prepare_notebook_for_save,
-    validate_jupytext_configuration_file,
 )
 from .formats import (
     long_form_multiple_formats,
@@ -39,7 +39,7 @@ from .paired_paths import (
     full_path,
     paired_paths,
 )
-from .pairs import latest_inputs_and_outputs, read_pair, write_pair
+from .pairs import PairedFilesDiffer, latest_inputs_and_outputs, read_pair, write_pair
 
 
 def build_jupytext_contents_manager_class(base_contents_manager_class):
@@ -58,17 +58,15 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
             self.paired_notebooks = dict()
 
             # Configuration cache, useful when notebooks are listed in a given directory
-            self.cached_config = namedtuple(
-                "cached_config", "path timestamp config_file config"
-            )
+            self.cached_config = namedtuple("cached_config", "path config_file config")
             self.super = super(JupytextContentsManager, self)
             self.super.__init__(*args, **kwargs)
 
-        def all_nb_extensions(self):
+        def all_nb_extensions(self, config):
             """All extensions that should be classified as notebooks"""
             return [
                 ext if ext.startswith(".") else "." + ext
-                for ext in self.notebook_extensions.split(",")
+                for ext in config.notebook_extensions
             ]
 
         def drop_paired_notebook(self, path):
@@ -122,7 +120,7 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
             nbk = model["content"]
             try:
                 config = self.get_config(path)
-                jupytext_formats = prepare_notebook_for_save(nbk, config, path)
+                jupytext_formats = notebook_formats(nbk, config, path)
                 self.update_paired_notebooks(path, jupytext_formats)
 
                 def save_one_file(path, fmt):
@@ -161,7 +159,7 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
                         type="file",
                         format="text",
                         content=jupytext.writes(
-                            nbformat.from_dict(model["content"]), fmt=fmt
+                            nbformat.from_dict(model["content"]), fmt=fmt, config=config
                         ),
                     )
 
@@ -185,7 +183,7 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
             format=None,
             load_alternative_format=True,
         ):
-            """ Takes a path for an entity and returns its model"""
+            """Takes a path for an entity and returns its model"""
             path = path.strip("/")
             ext = os.path.splitext(path)[1]
 
@@ -193,25 +191,29 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
             if (
                 not self.file_exists(path)
                 or self.dir_exists(path)
-                or (type != "notebook" if type else ext not in self.all_nb_extensions())
+                or (type is not None and type != "notebook")
             ):
                 return self.super.get(path, content, type, format)
 
             config = self.get_config(path, use_cache=content is False)
+            if ext not in self.all_nb_extensions(config):
+                return self.super.get(path, content, type, format)
+
             fmt = preferred_format(ext, config.preferred_jupytext_formats_read)
             if ext == ".ipynb":
                 model = self.super.get(path, content, type="notebook", format=format)
             else:
                 model = self.super.get(path, content, type="file", format=format)
                 model["type"] = "notebook"
-                config.set_default_format_options(fmt, read=True)
                 if content:
                     # We may need to update these keys, inherited from text files formats
                     # Cf. https://github.com/mwouts/jupytext/issues/659
                     model["format"] = "json"
                     model["mimetype"] = None
                     try:
-                        model["content"] = jupytext.reads(model["content"], fmt=fmt)
+                        model["content"] = jupytext.reads(
+                            model["content"], fmt=fmt, config=config
+                        )
                     except Exception as err:
                         self.log.error(
                             u"Error while reading file: %s %s", path, err, exc_info=True
@@ -289,11 +291,10 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
                     )["content"]
 
                 self.log.info(u"Reading SOURCE from {}".format(alt_path))
-                config.set_default_format_options(alt_fmt, read=True)
                 text = self.super.get(
                     alt_path, content=True, type="file", format=format
                 )["content"]
-                return jupytext.reads(text, fmt=alt_fmt)
+                return jupytext.reads(text, fmt=alt_fmt, config=config)
 
             inputs, outputs = latest_inputs_and_outputs(
                 path, fmt, formats, get_timestamp, contents_manager_mode=True
@@ -301,6 +302,7 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
 
             # Before we combine the two files, we make sure we're not overwriting ipynb cells
             # with an outdated text file
+            content = None
             try:
                 if (
                     outputs.timestamp
@@ -308,48 +310,68 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
                     > inputs.timestamp
                     + timedelta(seconds=config.outdated_text_notebook_margin)
                 ):
-                    raise HTTPError(
-                        400,
-                        """{out} (last modified {out_last})
-                        seems more recent than {src} (last modified {src_last})
-                        Please either:
-                        - open {src} in a text editor, make sure it is up to date, and save it,
-                        - or delete {src} if not up to date,
-                        - or increase check margin by adding, say,
-                            outdated_text_notebook_margin = 5  # default is 1 (second)
-                        to your jupytext.toml file
-                        """.format(
+                    ts_mismatch = (
+                        "{out} (last modified {out_last}) is more recent than "
+                        "{src} (last modified {src_last})".format(
                             src=inputs.path,
                             src_last=inputs.timestamp,
                             out=outputs.path,
                             out_last=outputs.timestamp,
-                        ),
+                        )
                     )
+                    self.log.warning(ts_mismatch)
+
+                    try:
+                        content = read_pair(
+                            inputs, outputs, read_one_file, must_match=True
+                        )
+                        self.log.warning(
+                            "The inputs in {src} and {out} are identical, "
+                            "so the mismatch in timestamps was ignored".format(
+                                src=inputs.path, out=outputs.path
+                            )
+                        )
+                    except HTTPError:
+                        raise
+                    except PairedFilesDiffer as diff:
+                        raise HTTPError(
+                            400,
+                            """{ts_mismatch}
+
+Differences (jupytext --diff {src} {out}) are:
+{diff}
+Please either:
+- open {src} in a text editor, make sure it is up to date, and save it,
+- or delete {src} if not up to date,
+- or increase check margin by adding, say,
+outdated_text_notebook_margin = 5  # default is 1 (second)
+to your jupytext.toml file
+                        """.format(
+                                ts_mismatch=ts_mismatch,
+                                src=inputs.path,
+                                out=outputs.path,
+                                diff=diff,
+                            ),
+                        )
             except OverflowError:
                 pass
 
-            try:
-                model["content"] = read_pair(inputs, outputs, read_one_file)
-            except HTTPError:
-                raise
-            except Exception as err:
-                self.log.error(
-                    u"Error while reading file: %s %s", path, err, exc_info=True
-                )
-                raise HTTPError(500, str(err))
+            if content is not None:
+                model["content"] = content
+            else:
+                try:
+                    model["content"] = read_pair(inputs, outputs, read_one_file)
+                except HTTPError:
+                    raise
+                except Exception as err:
+                    self.log.error(
+                        u"Error while reading file: %s %s", path, err, exc_info=True
+                    )
+                    raise HTTPError(500, str(err))
 
             if not outputs.timestamp:
                 set_kernelspec_from_language(model["content"])
 
-            # Trust code cells when they have no output
-            for cell in model["content"].cells:
-                if (
-                    cell.cell_type == "code"
-                    and not cell.outputs
-                    and cell.metadata.get("trusted") is False
-                ):
-                    cell.metadata["trusted"] = True
-
             return model
 
         def new_untitled(self, path="", type="", ext=""):
@@ -372,7 +394,8 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
                 raise HTTPError(404, "No such directory: %s" % path)
 
             untitled = self.untitled_notebook
-            name = self.increment_notebook_filename(untitled + ext, path)
+            config = self.get_config(path)
+            name = self.increment_notebook_filename(config, untitled + ext, path)
             path = u"{0}/{1}".format(path, name)
 
             model = {"type": "notebook"}
@@ -384,7 +407,7 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
 
             return self.new(model, path)
 
-        def increment_notebook_filename(self, filename, path=""):
+        def increment_notebook_filename(self, config, filename, path=""):
             """Increment a notebook filename until it is unique, regardless of extension"""
             # Extract the full suffix from the filename (e.g. .tar.gz)
             path = path.strip("/")
@@ -400,7 +423,7 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
                 name = basename_i + ext
                 if not any(
                     self.exists(u"{}/{}{}".format(path, basename_i, nb_ext))
-                    for nb_ext in self.notebook_extensions.split(",")
+                    for nb_ext in config.notebook_extensions
                 ):
                     break
             return name
@@ -474,6 +497,15 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
                 if self.file_exists(path):
                     return path
 
+            pyproject_path = directory + "/" + PYPROJECT_FILE
+            if self.file_exists(pyproject_path):
+                import toml
+
+                model = self.get(pyproject_path, type="file")
+                doc = toml.loads(model["content"])
+                if doc.get("tool", {}).get("jupytext") is not None:
+                    return pyproject_path
+
             if not directory:
                 return None
 
@@ -489,27 +521,18 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
                 config_file = self._get_os_path(config_file)
                 is_os_path = True
             if is_os_path:
-                config_dict = load_jupytext_configuration_file(config_file)
-            else:
-                model = self.super.get(config_file, content=True, type="file")
-                config_dict = load_jupytext_configuration_file(
-                    config_file, model["content"]
-                )
-            return validate_jupytext_configuration_file(config_file, config_dict)
+                return load_jupytext_configuration_file(config_file)
+            model = self.super.get(config_file, content=True, type="file")
+            return load_jupytext_configuration_file(config_file, model["content"])
 
         def get_config(self, path, use_cache=False):
             """Return the Jupytext configuration for the given path"""
             parent_dir = self.get_parent_dir(path)
 
-            # When listing the notebooks for the tree view, we use a one-second
-            # cache for the configuration file
-            if (
-                not use_cache
-                or parent_dir != self.cached_config.path
-                or (
-                    self.cached_config.timestamp + timedelta(seconds=1) < datetime.now()
-                )
-            ):
+            # When listing the notebooks for the tree view, we use a cache for the configuration file
+            # The cache will be refreshed when a notebook is opened or saved, or when we go
+            # to a different directory.
+            if not use_cache or parent_dir != self.cached_config.path:
                 try:
                     config_file = self.get_config_file(parent_dir)
                     if config_file:
@@ -521,7 +544,6 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
                         )
                     self.cached_config.config_file = config_file
                     self.cached_config.path = parent_dir
-                    self.cached_config.timestamp = datetime.now()
                 except JupytextConfigurationError as err:
                     self.log.error(
                         u"Error while reading config file: %s %s",
@@ -538,6 +560,8 @@ def build_jupytext_contents_manager_class(base_contents_manager_class):
                     self.cached_config.config_file,
                 )
                 return self.cached_config.config
+            if isinstance(self.notebook_extensions, str):
+                self.notebook_extensions = self.notebook_extensions.split(",")
             return self
 
     return JupytextContentsManager
