@@ -38,6 +38,7 @@ from .metadata_filter import filter_metadata, update_metadata_filters
 from .myst import MYST_FORMAT_NAME, myst_extensions, myst_to_notebook, notebook_to_myst
 from .pandoc import md_to_notebook, notebook_to_md
 from .pep8 import pep8_lines_between_cells
+from .quarto import notebook_to_qmd, qmd_to_notebook
 from .version import __version__
 
 
@@ -48,22 +49,37 @@ class NotSupportedNBFormatVersion(NotImplementedError):
 class TextNotebookConverter(NotebookReader, NotebookWriter):
     """A class that can read or write a Jupyter notebook as text"""
 
-    def __init__(self, fmt):
+    def __init__(self, fmt, config):
         self.fmt = copy(long_form_one_format(fmt))
+        self.config = config
         self.ext = self.fmt["extension"]
         self.implementation = get_format_implementation(
             self.ext, self.fmt.get("format_name")
         )
 
-    def update_fmt_with_notebook_options(self, metadata):
+    def update_fmt_with_notebook_options(self, metadata, read=False):
         """Update format options with the values in the notebook metadata, and record those
         options in the notebook metadata"""
-        # format options in notebook have precedence over that in fmt
+        # The settings in the Jupytext configuration file have precedence over the metadata in the notebook
+        # when the notebook is saved. This is because the metadata in the notebook might not be visible
+        # in the text representation when e.g. notebook_metadata_filter="-all", which makes them hard to edit.
+        if not read and self.config is not None:
+            self.config.set_default_format_options(self.fmt, read)
+
+        # Use format options from the notebook if not already set by the config
         for opt in _VALID_FORMAT_OPTIONS:
             if opt in metadata.get("jupytext", {}):
                 self.fmt.setdefault(opt, metadata["jupytext"][opt])
+
+        # When we read the notebook we use the values of the config as defaults, as again the text representation
+        # of the notebook might not store the format options when notebook_metadata_filter="-all"
+        if read and self.config is not None:
+            self.config.set_default_format_options(self.fmt, read=read)
+
+        # We save the format options in the notebook metadata
+        for opt in _VALID_FORMAT_OPTIONS:
             if opt in self.fmt:
-                metadata.setdefault("jupytext", {}).setdefault(opt, self.fmt[opt])
+                metadata.setdefault("jupytext", {})[opt] = self.fmt[opt]
 
         # Is this format the same as that documented in the YAML header? If so, we want to know the format version
         file_fmt = metadata.get("jupytext", {}).get("text_representation", {})
@@ -81,6 +97,9 @@ class TextNotebookConverter(NotebookReader, NotebookWriter):
         if self.fmt.get("format_name") == "pandoc":
             return md_to_notebook(s)
 
+        if self.fmt.get("format_name") == "quarto":
+            return qmd_to_notebook(s)
+
         if self.fmt.get("format_name") == MYST_FORMAT_NAME:
             return myst_to_notebook(s)
 
@@ -91,12 +110,17 @@ class TextNotebookConverter(NotebookReader, NotebookWriter):
             lines,
             self.implementation.header_prefix,
             self.implementation.extension,
-            self.fmt.get("root_level_metadata_as_raw_cell", True),
+            self.fmt.get(
+                "root_level_metadata_as_raw_cell",
+                self.config.root_level_metadata_as_raw_cell
+                if self.config is not None
+                else True,
+            ),
         )
         default_language = default_language_from_metadata_and_ext(
             metadata, self.implementation.extension
         )
-        self.update_fmt_with_notebook_options(metadata)
+        self.update_fmt_with_notebook_options(metadata, read=True)
 
         if header_cell:
             cells.append(header_cell)
@@ -153,78 +177,50 @@ class TextNotebookConverter(NotebookReader, NotebookWriter):
 
         return new_notebook(cells=cells, metadata=metadata)
 
+    def filter_notebook(self, nb, metadata):
+        self.update_fmt_with_notebook_options(nb.metadata)
+        metadata = insert_jupytext_info_and_filter_metadata(
+            metadata, self.fmt, self.implementation
+        )
+
+        cells = []
+        for cell in nb.cells:
+            cell_metadata = filter_metadata(
+                cell.metadata,
+                self.fmt.get("cell_metadata_filter"),
+                _IGNORE_CELL_METADATA,
+            )
+            if cell.cell_type == "code":
+                cells.append(new_code_cell(source=cell.source, metadata=cell_metadata))
+            else:
+                cells.append(
+                    NotebookNode(
+                        source=cell.source,
+                        metadata=cell_metadata,
+                        cell_type=cell.cell_type,
+                    )
+                )
+        return NotebookNode(
+            nbformat=nb.nbformat,
+            nbformat_minor=nb.nbformat_minor,
+            metadata=metadata,
+            cells=cells,
+        )
+
     def writes(self, nb, metadata=None, **kwargs):
         """Return the text representation of the notebook"""
         if self.fmt.get("format_name") == "pandoc":
-            metadata = insert_jupytext_info_and_filter_metadata(
-                metadata, self.ext, self.implementation
-            )
-
-            cells = []
-            for cell in nb.cells:
-                cell_metadata = filter_metadata(
-                    cell.metadata,
-                    self.fmt.get("cell_metadata_filter"),
-                    _IGNORE_CELL_METADATA,
-                )
-                if cell.cell_type == "code":
-                    cells.append(
-                        new_code_cell(source=cell.source, metadata=cell_metadata)
-                    )
-                else:
-                    cells.append(
-                        NotebookNode(
-                            source=cell.source,
-                            metadata=cell_metadata,
-                            cell_type=cell.cell_type,
-                        )
-                    )
-
-            return notebook_to_md(
-                NotebookNode(
-                    nbformat=nb.nbformat,
-                    nbformat_minor=nb.nbformat_minor,
-                    metadata=metadata,
-                    cells=cells,
-                )
-            )
-
+            return notebook_to_md(self.filter_notebook(nb, metadata))
+        if self.fmt.get("format_name") == "quarto" or self.ext == ".qmd":
+            return notebook_to_qmd(self.filter_notebook(nb, metadata))
         if self.fmt.get(
             "format_name"
         ) == MYST_FORMAT_NAME or self.ext in myst_extensions(no_md=True):
             pygments_lexer = metadata.get("language_info", {}).get(
                 "pygments_lexer", None
             )
-            metadata = insert_jupytext_info_and_filter_metadata(
-                metadata, self.ext, self.implementation
-            )
-
-            cells = []
-            for cell in nb.cells:
-                cell_metadata = filter_metadata(
-                    cell.metadata,
-                    self.fmt.get("cell_metadata_filter"),
-                    _IGNORE_CELL_METADATA,
-                )
-                if cell.cell_type == "code":
-                    cells.append(
-                        new_code_cell(source=cell.source, metadata=cell_metadata)
-                    )
-                else:
-                    cells.append(
-                        NotebookNode(
-                            source=cell.source,
-                            metadata=cell_metadata,
-                            cell_type=cell.cell_type,
-                        )
-                    )
             return notebook_to_myst(
-                NotebookNode(
-                    nbformat=nb.nbformat,
-                    nbformat_minor=nb.nbformat_minor,
-                    metadata=metadata,
-                    cells=cells,
-                ),
+                self.filter_notebook(nb, metadata),
                 default_lexer=pygments_lexer,
             )
 
@@ -257,8 +253,7 @@ class TextNotebookConverter(NotebookReader, NotebookWriter):
             nb,
             metadata,
             self.implementation,
-            self.ext,
-            self.fmt.get("root_level_metadata_as_raw_cell", True),
+            self.fmt,
         )
         header.extend(header_content)
 
@@ -334,13 +329,14 @@ class TextNotebookConverter(NotebookReader, NotebookWriter):
         return "\n".join(header + lines)
 
 
-def reads(text, fmt, as_version=nbformat.NO_CONVERT, **kwargs):
+def reads(text, fmt=None, as_version=nbformat.NO_CONVERT, config=None, **kwargs):
     """
     Read a notebook from a string
 
     :param text: the text representation of the notebook
     :param fmt: (optional) the jupytext format like `md`, `py:percent`, ...
     :param as_version: see nbformat.reads
+    :param config: (optional) a Jupytext configuration object
     :param kwargs: (not used) additional parameters for nbformat.reads
     :return: the notebook
     """
@@ -370,7 +366,7 @@ def reads(text, fmt, as_version=nbformat.NO_CONVERT, **kwargs):
         fmt["format_name"] = format_name
 
     fmt.update(format_options)
-    reader = TextNotebookConverter(fmt)
+    reader = TextNotebookConverter(fmt, config)
     notebook = reader.reads(text, **kwargs)
     rearrange_jupytext_metadata(notebook.metadata)
 
@@ -382,12 +378,13 @@ def reads(text, fmt, as_version=nbformat.NO_CONVERT, **kwargs):
     return notebook
 
 
-def read(fp, as_version=nbformat.NO_CONVERT, fmt=None, **kwargs):
+def read(fp, as_version=nbformat.NO_CONVERT, fmt=None, config=None, **kwargs):
     """Read a notebook from a file name or a file object
 
     :param fp: a file name or a file object
     :param as_version: see nbformat.read
     :param fmt: (optional) the jupytext format like `md`, `py:percent`, ...
+    :param config: (optional) a Jupytext configuration object
     :param kwargs: (not used) additional parameters for nbformat.read
     :return: the notebook
     """
@@ -409,7 +406,7 @@ def read(fp, as_version=nbformat.NO_CONVERT, fmt=None, **kwargs):
             fmt = long_form_one_format(fmt)
         fmt.update({"extension": ext})
         with io.open(fp, encoding="utf-8") as stream:
-            return read(stream, as_version=as_version, fmt=fmt, **kwargs)
+            return read(stream, as_version=as_version, fmt=fmt, config=config, **kwargs)
 
     if fmt is not None:
         fmt = long_form_one_format(fmt)
@@ -418,15 +415,16 @@ def read(fp, as_version=nbformat.NO_CONVERT, fmt=None, **kwargs):
             rearrange_jupytext_metadata(notebook.metadata)
             return notebook
 
-    return reads(fp.read(), fmt, **kwargs)
+    return reads(fp.read(), fmt, config=config, **kwargs)
 
 
-def writes(notebook, fmt, version=nbformat.NO_CONVERT, **kwargs):
+def writes(notebook, fmt, version=nbformat.NO_CONVERT, config=None, **kwargs):
     """Return the text representation of the notebook
 
     :param notebook: the notebook
     :param fmt: the jupytext format like `md`, `py:percent`, ...
     :param version: see nbformat.writes
+    :param config: (optional) a Jupytext configuration object
     :param kwargs: (not used) additional parameters for nbformat.writes
     :return: the text representation of the notebook
     """
@@ -481,22 +479,23 @@ def writes(notebook, fmt, version=nbformat.NO_CONVERT, **kwargs):
         fmt["format_name"] = format_name
         update_jupytext_formats_metadata(metadata, fmt)
 
-    writer = TextNotebookConverter(fmt)
+    writer = TextNotebookConverter(fmt, config)
     return writer.writes(notebook, metadata)
 
 
-def write(nb, fp, version=nbformat.NO_CONVERT, fmt=None, **kwargs):
+def write(nb, fp, version=nbformat.NO_CONVERT, fmt=None, config=None, **kwargs):
     """Write a notebook to a file name or a file object
 
     :param nb: the notebook
     :param fp: a file name or a file object
     :param version: see nbformat.write
     :param fmt: (optional if fp is a file name) the jupytext format like `md`, `py:percent`, ...
+    :param config: (optional) a Jupytext configuration object
     :param kwargs: (not used) additional parameters for nbformat.write
     """
     if fp == "-":
         # Use sys.stdout.buffer when possible, and explicit utf-8 encoding, cf. #331
-        content = writes(nb, version=version, fmt=fmt, **kwargs)
+        content = writes(nb, version=version, fmt=fmt, config=config, **kwargs)
         try:
             # Python 3
             sys.stdout.buffer.write(content.encode("utf-8"))
@@ -513,14 +512,14 @@ def write(nb, fp, version=nbformat.NO_CONVERT, fmt=None, **kwargs):
         create_prefix_dir(fp, fmt)
 
         with io.open(fp, "w", encoding="utf-8") as stream:
-            write(nb, stream, version=version, fmt=fmt, **kwargs)
+            write(nb, stream, version=version, fmt=fmt, config=config, **kwargs)
             return
     else:
         assert (
             fmt is not None
         ), "'fmt' argument in jupytext.write is mandatory unless fp is a file name"
 
-    content = writes(nb, version=version, fmt=fmt, **kwargs)
+    content = writes(nb, version=version, fmt=fmt, config=config, **kwargs)
     if isinstance(content, bytes):
         content = content.decode("utf8")
     fp.write(content)
