@@ -1,4 +1,5 @@
 import os
+from copy import deepcopy
 from shutil import copyfile
 
 import pytest
@@ -110,9 +111,8 @@ def test_apply_black_through_jupytext(tmpdir, nb_file):
     compare_notebooks(nb_now, nb_black, compare_ids=True)
 
     # Write to another folder using dots
-    script_fmt = os.path.join("..", "script_folder//py:percent")
     write(nb_org, tmp_ipynb)
-    jupytext([tmp_ipynb, "--to", script_fmt, "--pipe", "black"])
+    jupytext([tmp_ipynb, "--to", "../script_folder//py:percent", "--pipe", "black"])
     assert os.path.isfile(tmp_py)
     nb_now = read(tmp_py)
     nb_now.metadata = metadata
@@ -285,3 +285,21 @@ def test_pipe_black_uses_warn_only_781(
     # If black fails the notebook should be left unchanged
     actual = read("notebook.ipynb")
     compare_notebooks(actual, nb)
+
+
+@requires_black
+def test_pipe_black_preserve_outputs(notebook_with_outputs, tmpdir, cwd_tmpdir, capsys):
+    write(notebook_with_outputs, "test.ipynb")
+    jupytext(["--pipe", "black", "test.ipynb"])
+
+    # Outputs are preserved
+    nb = read("test.ipynb")
+    expected = deepcopy(notebook_with_outputs)
+    expected.cells[0].source = "1 + 1"
+    compare_notebooks(nb, expected)
+
+    # No mention of --update
+    out, err = capsys.readouterr()
+    assert not err
+    assert "replaced" not in out
+    assert "--update" not in out
