@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 
-import itertools
 import os
 import sys
 import time
 import unittest.mock as mock
+import warnings
 from argparse import ArgumentTypeError
+from contextlib import contextmanager
 from io import StringIO
 from shutil import copyfile
 from subprocess import check_call
@@ -727,7 +728,7 @@ def test_format_prefix_suffix(tmpdir, cwd_tmpdir):
     tmp_py = "scripts/notebook_name.py"
     write(new_notebook(), tmp_ipynb)
 
-    jupytext([tmp_ipynb, "--to", os.path.join("..", "scripts//py")])
+    jupytext([tmp_ipynb, "--to", "../scripts//py"])
     assert os.path.isfile(tmp_py)
     os.remove(tmp_py)
 
@@ -861,10 +862,8 @@ def test_remove_jupytext_metadata(tmpdir, cwd_tmpdir):
     }
 
 
-@pytest.mark.parametrize(
-    "nb_file,fmt",
-    itertools.product(list_notebooks("ipynb_py"), ["py:light", "py:percent", "md"]),
-)
+@pytest.mark.parametrize("nb_file", list_notebooks("ipynb_py"))
+@pytest.mark.parametrize("fmt", ["py:light", "py:percent", "md"])
 def test_convert_and_update_preserves_notebook(nb_file, fmt, tmpdir, cwd_tmpdir):
     # cannot encode magic parameters in markdown yet
     if ("magic" in nb_file or "LateX" in nb_file) and fmt == "md":
@@ -880,6 +879,12 @@ def test_convert_and_update_preserves_notebook(nb_file, fmt, tmpdir, cwd_tmpdir)
 
     nb_org = read(nb_file)
     nb_now = read(tmp_ipynb)
+
+    # The cell marker changes from """ to r""" on the LateX notebook #836
+    if "LateX" in nb_file and fmt == "py:percent":
+        last_cell = nb_now.cells[-1]
+        last_cell.metadata["cell_marker"] = last_cell.metadata["cell_marker"][1:]
+
     compare(nb_now, nb_org)
 
 
@@ -1127,6 +1132,28 @@ def test_sync_script_dotdot_folder_564(tmpdir):
     jupytext(["--sync", str(nb_file)])
 
 
+@contextmanager
+def no_warning():
+    with pytest.warns(None) as records:
+        yield
+
+    # There should be no warning
+    for record in records:
+        # Temporary exception for for this one, see #865
+        if (
+            "Passing a schema to Validator.iter_errors is deprecated "
+            "and will be removed in a future release" in str(record.message)
+        ):
+            continue
+        raise RuntimeError(record)
+
+
+def test_no_warning():
+    with pytest.raises(RuntimeError, match="a sample warning"):
+        with no_warning():
+            warnings.warn("a sample warning")
+
+
 def test_jupytext_to_file_emits_a_warning(tmpdir):
     """The user may type
         jupytext notebook.ipynb --to script.py
@@ -1138,11 +1165,9 @@ def test_jupytext_to_file_emits_a_warning(tmpdir):
     nb_file = tmpdir.join("notebook.ipynb")
     write(new_notebook(), str(nb_file))
 
-    with pytest.warns(None) as record:
+    with no_warning():
         jupytext(["notebook.ipynb", "-o", "script.py"])
 
-    assert len(record) == 0
-
     with pytest.warns(UserWarning, match="Maybe you want to use the '-o' option"):
         jupytext(["notebook.ipynb", "--to", "script.py"])
 
@@ -1161,11 +1186,9 @@ def test_jupytext_set_formats_file_gives_an_informative_error(tmpdir, cwd_tmpdir
     nb_file = tmpdir.join("notebook.ipynb")
     md_file.write("Some text")
 
-    with pytest.warns(None) as warnings:
+    with no_warning():
         jupytext(["--sync", "notebook.md"])
 
-    assert not warnings
-
     assert py_file.exists()
     assert nb_file.exists()
 
@@ -1180,7 +1203,16 @@ def test_diff(tmpdir, cwd_tmpdir, capsys):
     write(new_notebook(cells=[new_code_cell("1 + 1")]), "test.ipynb")
     write(new_notebook(cells=[new_code_cell("2 + 2")]), "test.py", fmt="py:percent")
 
-    jupytext(["--to", "py:percent", "test.ipynb", "--diff"])
+    jupytext(["--diff", "test.py", "test.ipynb"])
+    captured = capsys.readouterr()
+    assert "-2 + 2\n+1 + 1" in captured.out
+
+
+def test_show_changes(tmpdir, cwd_tmpdir, capsys):
+    write(new_notebook(cells=[new_code_cell("1 + 1")]), "test.ipynb")
+    write(new_notebook(cells=[new_code_cell("2 + 2")]), "test.py", fmt="py:percent")
+
+    jupytext(["--to", "py:percent", "test.ipynb", "--show-changes"])
     captured = capsys.readouterr()
     assert "-2 + 2\n+1 + 1" in captured.out
 
@@ -1356,7 +1388,7 @@ def test_use_source_timestamp(tmpdir, cwd_tmpdir, python_notebook, capsys, forma
     if formats == "ipynb,py":
         from tornado.web import HTTPError
 
-        with pytest.raises(HTTPError, match="seems more recent than test.py"):
+        with pytest.raises(HTTPError, match="is more recent than test.py"):
             cm.get("test.ipynb")
     else:
         cm.get("test.ipynb")
