@@ -23,6 +23,7 @@ from .utils import (
     list_notebooks,
     notebook_model,
     requires_pandoc,
+    requires_quarto,
     requires_sphinx_gallery,
 )
 
@@ -121,7 +122,7 @@ def test_load_save_rename(nb_file, tmpdir):
     tmp_rmd = "notebook.Rmd"
 
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "ipynb,Rmd"
+    cm.formats = "ipynb,Rmd"
     cm.root_dir = str(tmpdir)
 
     # open ipynb, save Rmd, reopen
@@ -200,6 +201,33 @@ def test_save_load_paired_md_pandoc_notebook(nb_file, tmpdir):
     assert nb_md["content"].metadata["jupytext"]["formats"] == "ipynb,md:pandoc"
 
 
+@requires_quarto
+@pytest.mark.parametrize(
+    "nb_file",
+    list_notebooks(
+        "ipynb",
+        skip="(World|functional|Notebook with|plotly_graphs|flavors|complex_metadata|"
+        "update83|raw_cell|_66|nteract|LaTeX|invalid|305|text_outputs|ir_notebook)",
+    ),
+)
+def test_save_load_paired_qmd_notebook(nb_file, tmpdir):
+    tmp_ipynb = "notebook.ipynb"
+    tmp_qmd = "notebook.qmd"
+
+    cm = jupytext.TextFileContentsManager()
+    cm.root_dir = str(tmpdir)
+
+    # open ipynb, save with cm, reopen
+    nb = jupytext.read(nb_file)
+    nb.metadata["jupytext"] = {"formats": "ipynb,qmd"}
+
+    cm.save(model=notebook_model(nb), path=tmp_ipynb)
+    nb_md = cm.get(tmp_qmd)
+
+    compare_notebooks(nb_md["content"], nb, "qmd")
+    assert nb_md["content"].metadata["jupytext"]["formats"] == "ipynb,qmd"
+
+
 @pytest.mark.parametrize("py_file", list_notebooks("percent"))
 def test_pair_plain_script(py_file, tmpdir, caplog):
     tmp_py = "notebook.py"
@@ -248,7 +276,7 @@ def test_load_save_rename_nbpy(nb_file, tmpdir):
     tmp_nbpy = "notebook.nb.py"
 
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "ipynb,.nb.py"
+    cm.formats = "ipynb,.nb.py"
     cm.root_dir = str(tmpdir)
 
     # open ipynb, save nb.py, reopen
@@ -330,7 +358,7 @@ def test_load_save_rename_notebook_with_dot(nb_file, tmpdir):
     tmp_nbpy = "1.notebook.py"
 
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "ipynb,py"
+    cm.formats = "ipynb,py"
     cm.root_dir = str(tmpdir)
 
     # open ipynb, save nb.py, reopen
@@ -357,7 +385,7 @@ def test_load_save_rename_nbpy_default_config(nb_file, tmpdir):
     tmp_nbpy = "notebook.nb.py"
 
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "ipynb,.nb.py"
+    cm.formats = "ipynb,.nb.py"
     cm.root_dir = str(tmpdir)
 
     # open ipynb, save nb.py, reopen
@@ -397,7 +425,7 @@ def test_load_save_rename_non_ascii_path(nb_file, tmpdir):
     tmp_nbpy = u"notebôk.nb.py"
 
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "ipynb,.nb.py"
+    cm.formats = "ipynb,.nb.py"
     tmpdir = u"" + str(tmpdir)
     cm.root_dir = tmpdir
 
@@ -435,19 +463,52 @@ def test_load_save_rename_non_ascii_path(nb_file, tmpdir):
 @pytest.mark.parametrize("nb_file", list_notebooks("ipynb_py")[:1])
 def test_outdated_text_notebook(nb_file, tmpdir):
     # 1. write py ipynb
-    tmp_ipynb = u"notebook.ipynb"
-    tmp_nbpy = u"notebook.py"
-
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "py,ipynb"
+    cm.formats = "py,ipynb"
     cm.outdated_text_notebook_margin = 0
     cm.root_dir = str(tmpdir)
 
     # open ipynb, save py, reopen
     nb = jupytext.read(nb_file)
-    cm.save(model=notebook_model(nb), path=tmp_nbpy)
-    model_py = cm.get(tmp_nbpy, load_alternative_format=False)
-    model_ipynb = cm.get(tmp_ipynb, load_alternative_format=False)
+    cm.save(model=notebook_model(nb), path="notebook.py")
+    model_py = cm.get("notebook.py", load_alternative_format=False)
+    model_ipynb = cm.get("notebook.ipynb", load_alternative_format=False)
+
+    # 2. check that time of ipynb <= py
+    assert model_ipynb["last_modified"] <= model_py["last_modified"]
+
+    # 3. wait some time
+    time.sleep(0.5)
+
+    # 4. modify ipynb
+    nb.cells.append(new_markdown_cell("New cell"))
+    write(nb, str(tmpdir.join("notebook.ipynb")))
+
+    # 5. test error
+    with pytest.raises(HTTPError):
+        cm.get("notebook.py")
+
+    # 6. test OK with
+    cm.outdated_text_notebook_margin = 1.0
+    cm.get("notebook.py")
+
+    # 7. test OK with
+    cm.outdated_text_notebook_margin = float("inf")
+    cm.get("notebook.py")
+
+
+def test_outdated_text_notebook_no_diff_ok(tmpdir, python_notebook):
+    # 1. write py ipynb
+    cm = jupytext.TextFileContentsManager()
+    cm.formats = "py,ipynb"
+    cm.outdated_text_notebook_margin = 0
+    cm.root_dir = str(tmpdir)
+
+    # open ipynb, save py, reopen
+    nb = python_notebook
+    cm.save(model=notebook_model(nb), path="notebook.py")
+    model_py = cm.get("notebook.py", load_alternative_format=False)
+    model_ipynb = cm.get("notebook.ipynb", load_alternative_format=False)
 
     # 2. check that time of ipynb <= py
     assert model_ipynb["last_modified"] <= model_py["last_modified"]
@@ -456,20 +517,61 @@ def test_outdated_text_notebook(nb_file, tmpdir):
     time.sleep(0.5)
 
     # 4. touch ipynb
-    with open(str(tmpdir.join(tmp_ipynb)), "a"):
-        os.utime(str(tmpdir.join(tmp_ipynb)), None)
+    with open(tmpdir / "notebook.ipynb", "a"):
+        os.utime(tmpdir / "notebook.ipynb", None)
 
-    # 5. test error
-    with pytest.raises(HTTPError):
-        cm.get(tmp_nbpy)
+    # 5. No error since both files correspond to the same notebook #799
+    cm.get("notebook.py")
 
-    # 6. test OK with
-    cm.outdated_text_notebook_margin = 1.0
-    cm.get(tmp_nbpy)
 
-    # 7. test OK with
-    cm.outdated_text_notebook_margin = float("inf")
-    cm.get(tmp_nbpy)
+def test_outdated_text_notebook_diff_is_shown(tmpdir, python_notebook):
+    # 1. write py ipynb
+    cm = jupytext.TextFileContentsManager()
+    cm.formats = "py,ipynb"
+    cm.outdated_text_notebook_margin = 0
+    cm.root_dir = str(tmpdir)
+
+    # open ipynb, save py, reopen
+    nb = python_notebook
+    nb.cells = [new_markdown_cell("Text version 1.0")]
+    cm.save(model=notebook_model(nb), path="notebook.py")
+    model_py = cm.get("notebook.py", load_alternative_format=False)
+    model_ipynb = cm.get("notebook.ipynb", load_alternative_format=False)
+
+    # 2. check that time of ipynb <= py
+    assert model_ipynb["last_modified"] <= model_py["last_modified"]
+
+    # 3. wait some time
+    time.sleep(0.5)
+
+    # 4. modify ipynb
+    nb.cells = [new_markdown_cell("Text version 2.0")]
+    jupytext.write(nb, str(tmpdir / "notebook.ipynb"))
+
+    # 5. The diff is shown in the error
+    with pytest.raises(HTTPError) as excinfo:
+        cm.get("notebook.py")
+
+    diff = excinfo.value.log_message
+
+    diff = diff[diff.find("Differences") : diff.rfind("Please")]
+
+    compare(
+        # In the reference below, lines with a single space
+        # have been stripped by the pre-commit hook
+        diff.replace("\n \n", "\n\n"),
+        """Differences (jupytext --diff notebook.py notebook.ipynb) are:
+--- notebook.py
++++ notebook.ipynb
+@@ -12,5 +12,5 @@
+ #     name: python_kernel
+ # ---
+
+-# Text version 1.0
++# Text version 2.0
+
+""",
+    )
 
 
 @pytest.mark.parametrize("nb_file", list_notebooks("ipynb_py")[:1])
@@ -558,13 +660,13 @@ def test_save_to_percent_format(nb_file, tmpdir):
 def test_save_using_preferred_and_default_format_170(nb_file, tmpdir):
     nb = read(nb_file)
 
-    # Way 0: preferred_jupytext_formats_save, no prefix + default_jupytext_formats
+    # Way 0: preferred_jupytext_formats_save, no prefix + formats
     tmp_py = str(tmpdir.join("python/notebook.py"))
 
     cm = jupytext.TextFileContentsManager()
     cm.root_dir = str(tmpdir)
     cm.preferred_jupytext_formats_save = "py:percent"
-    cm.default_jupytext_formats = "ipynb,python//py"
+    cm.formats = "ipynb,python//py"
 
     # save to ipynb and py
     cm.save(model=notebook_model(nb), path="notebook.ipynb")
@@ -573,13 +675,13 @@ def test_save_using_preferred_and_default_format_170(nb_file, tmpdir):
     nb_py = read(tmp_py)
     assert nb_py.metadata["jupytext"]["text_representation"]["format_name"] == "percent"
 
-    # Way 1: preferred_jupytext_formats_save + default_jupytext_formats
+    # Way 1: preferred_jupytext_formats_save + formats
     tmp_py = str(tmpdir.join("python/notebook.py"))
 
     cm = jupytext.TextFileContentsManager()
     cm.root_dir = str(tmpdir)
     cm.preferred_jupytext_formats_save = "python//py:percent"
-    cm.default_jupytext_formats = "ipynb,python//py"
+    cm.formats = "ipynb,python//py"
 
     # save to ipynb and py
     cm.save(model=notebook_model(nb), path="notebook.ipynb")
@@ -588,12 +690,12 @@ def test_save_using_preferred_and_default_format_170(nb_file, tmpdir):
     nb_py = read(tmp_py)
     assert nb_py.metadata["jupytext"]["text_representation"]["format_name"] == "percent"
 
-    # Way 2: default_jupytext_formats
+    # Way 2: formats
     tmp_py = str(tmpdir.join("python/notebook.py"))
 
     cm = jupytext.TextFileContentsManager()
     cm.root_dir = str(tmpdir)
-    cm.default_jupytext_formats = "ipynb,python//py:percent"
+    cm.formats = "ipynb,python//py:percent"
 
     # save to ipynb and py
     cm.save(model=notebook_model(nb), path="notebook.ipynb")
@@ -613,9 +715,9 @@ def test_open_using_preferred_and_default_format_174(nb_file, tmpdir):
 
     cm = jupytext.TextFileContentsManager()
     cm.root_dir = str(tmpdir)
-    cm.default_jupytext_formats = "ipynb,python//py:percent"
-    cm.default_notebook_metadata_filter = "all"
-    cm.default_cell_metadata_filter = "all"
+    cm.formats = "ipynb,python//py:percent"
+    cm.notebook_metadata_filter = "all"
+    cm.cell_metadata_filter = "all"
 
     # load notebook
     model = cm.get("notebook.ipynb")
@@ -647,8 +749,8 @@ def test_kernelspec_are_preserved(nb_file, tmpdir):
 
     cm = jupytext.TextFileContentsManager()
     cm.root_dir = str(tmpdir)
-    cm.default_jupytext_formats = "ipynb,py"
-    cm.default_notebook_metadata_filter = "-all"
+    cm.formats = "ipynb,py"
+    cm.notebook_metadata_filter = "-all"
 
     # load notebook
     model = cm.get("notebook.ipynb")
@@ -818,7 +920,7 @@ def test_save_in_auto_extension_global(nb_file, tmpdir):
 
     # create contents manager with default load format as percent
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "ipynb,auto"
+    cm.formats = "ipynb,auto"
     cm.preferred_jupytext_formats_save = "auto:percent"
     cm.root_dir = str(tmpdir)
 
@@ -846,7 +948,7 @@ def test_global_auto_pairing_works_with_empty_notebook(tmpdir):
 
     # create contents manager with default load format as percent
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "ipynb,auto"
+    cm.formats = "ipynb,auto"
     cm.preferred_jupytext_formats_save = "auto:percent"
     cm.root_dir = str(tmpdir)
 
@@ -902,7 +1004,7 @@ def test_save_in_auto_extension_global_with_format(nb_file, tmpdir):
 
     # create contents manager with default load format as percent
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "ipynb,auto:percent"
+    cm.formats = "ipynb,auto:percent"
     cm.root_dir = str(tmpdir)
 
     # save notebook
@@ -960,7 +1062,7 @@ def test_save_in_pct_and_lgt_auto_extensions(nb_file, tmpdir):
 
     # create contents manager with default load format as percent
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "ipynb,.pct.auto,.lgt.auto"
+    cm.formats = "ipynb,.pct.auto,.lgt.auto"
     cm.preferred_jupytext_formats_save = ".pct.auto:percent,.lgt.auto:light"
     cm.root_dir = str(tmpdir)
 
@@ -990,9 +1092,9 @@ def test_metadata_filter_is_effective(nb_file, tmpdir):
     cm.save(model=notebook_model(nb), path=tmp_ipynb)
 
     # set config
-    cm.default_jupytext_formats = "ipynb,py"
-    cm.default_notebook_metadata_filter = "jupytext,-all"
-    cm.default_cell_metadata_filter = "-all"
+    cm.formats = "ipynb,py"
+    cm.notebook_metadata_filter = "jupytext,-all"
+    cm.cell_metadata_filter = "-all"
 
     # load notebook
     nb = cm.get(tmp_ipynb)["content"]
@@ -1038,8 +1140,8 @@ print('hello2')
 
     # Andre's config #139
     cm.freeze_metadata = True
-    cm.default_notebook_metadata_filter = "-all"
-    cm.default_cell_metadata_filter = "-lines_to_next_cell"
+    cm.notebook_metadata_filter = "-all"
+    cm.cell_metadata_filter = "-lines_to_next_cell"
 
     # load notebook
     model = cm.get("script.py")
@@ -1072,7 +1174,7 @@ def test_local_format_can_deactivate_pairing(nb_file, ext, tmpdir):
 
     # create contents manager with default pairing
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "ipynb,py"
+    cm.formats = "ipynb,py"
     cm.root_dir = str(tmpdir)
 
     # save notebook
@@ -1100,7 +1202,7 @@ def test_global_pairing_allows_to_save_other_file_types(nb_file, tmpdir):
 
     # create contents manager with default pairing
     cm = jupytext.TextFileContentsManager()
-    cm.default_jupytext_formats = "ipynb,py"
+    cm.formats = "ipynb,py"
     cm.root_dir = str(tmpdir)
 
     # save notebook
@@ -1344,11 +1446,11 @@ def test_share_py_recreate_ipynb(tmpdir, nb_file):
     cm.preferred_jupytext_formats_save = "py:percent"
 
     # every new file is paired
-    cm.default_jupytext_formats = "ipynb,py"
+    cm.formats = "ipynb,py"
 
     # the text files don't need a YAML header
-    cm.default_notebook_metadata_filter = "-all"
-    cm.default_cell_metadata_filter = "-all"
+    cm.notebook_metadata_filter = "-all"
+    cm.cell_metadata_filter = "-all"
 
     nb = read(nb_file)
     model_ipynb = cm.save(model=notebook_model(nb), path="nb.ipynb")
@@ -1377,8 +1479,8 @@ def test_vim_folding_markers(tmpdir):
     cm.root_dir = str(tmpdir)
 
     # Default Vim folding markers
-    cm.default_cell_markers = "{{{,}}}"
-    cm.default_jupytext_formats = "ipynb,py"
+    cm.cell_markers = "{{{,}}}"
+    cm.formats = "ipynb,py"
 
     nb = new_notebook(
         cells=[
@@ -1433,8 +1535,8 @@ def test_vscode_pycharm_folding_markers(tmpdir):
     cm.root_dir = str(tmpdir)
 
     # Default VScode/PyCharm folding markers
-    cm.default_cell_markers = "region,endregion"
-    cm.default_jupytext_formats = "ipynb,py"
+    cm.cell_markers = "region,endregion"
+    cm.formats = "ipynb,py"
 
     nb = new_notebook(
         cells=[
@@ -1481,14 +1583,14 @@ b = 1
     )
 
 
-def test_open_file_with_default_cell_markers(tmpdir):
+def test_open_file_with_cell_markers(tmpdir):
     tmp_py = str(tmpdir.join("nb.py"))
 
     cm = jupytext.TextFileContentsManager()
     cm.root_dir = str(tmpdir)
 
     # Default VScode/PyCharm folding markers
-    cm.default_cell_markers = "region,endregion"
+    cm.cell_markers = "region,endregion"
 
     text = """# +
 # this is a unique code cell
@@ -1519,14 +1621,14 @@ def test_open_file_with_default_cell_markers(tmpdir):
     compare(text2, expected)
 
 
-def test_save_file_with_default_cell_markers(tmpdir):
+def test_save_file_with_cell_markers(tmpdir):
     tmp_py = str(tmpdir.join("nb.py"))
 
     cm = jupytext.TextFileContentsManager()
     cm.root_dir = str(tmpdir)
 
     # Default VScode/PyCharm folding markers
-    cm.default_cell_markers = "region,endregion"
+    cm.cell_markers = "region,endregion"
 
     text = """# +
 # this is a unique code cell
@@ -1541,37 +1643,57 @@ def test_save_file_with_default_cell_markers(tmpdir):
     nb = cm.get("nb.py")["content"]
     assert len(nb.cells) == 1
 
-    nb.metadata["jupytext"]["cell_markers"] = "+,-"
-    del nb.metadata["jupytext"]["notebook_metadata_filter"]
     cm.save(model=notebook_model(nb), path="nb.py")
 
     with open(tmp_py) as fp:
         text2 = fp.read()
 
     compare(
-        "\n".join(text2.splitlines()[-len(text.splitlines()) :]),
-        "\n".join(text.splitlines()),
+        text2,
+        """# region
+# this is a unique code cell
+1 + 1
+
+2 + 2
+# endregion
+""",
     )
 
     nb2 = cm.get("nb.py")["content"]
     compare_notebooks(nb2, nb)
-    assert nb2.metadata["jupytext"]["cell_markers"] == "+,-"
+    assert nb2.metadata["jupytext"]["cell_markers"] == "region,endregion"
 
 
-def test_notebook_extensions(tmpdir):
-    tmp_py = str(tmpdir.join("script.py"))
-    tmp_rmd = str(tmpdir.join("notebook.Rmd"))
-    tmp_ipynb = str(tmpdir.join("notebook.ipynb"))
-
+def test_notebook_extensions(tmpdir, cwd_tmpdir):
     nb = new_notebook()
-    write(nb, tmp_py)
-    write(nb, tmp_rmd)
-    write(nb, tmp_ipynb)
+    write(nb, "script.py")
+    write(nb, "notebook.Rmd")
+    write(nb, "notebook.ipynb")
+
+    cm = jupytext.TextFileContentsManager()
+    cm.root_dir = str(tmpdir)
+    cm.notebook_extensions = "ipynb,Rmd"
+
+    model = cm.get("notebook.ipynb")
+    assert model["type"] == "notebook"
+
+    model = cm.get("notebook.Rmd")
+    assert model["type"] == "notebook"
+
+    model = cm.get("script.py")
+    assert model["type"] == "file"
+
+
+def test_notebook_extensions_in_config(tmpdir, cwd_tmpdir):
+    nb = new_notebook()
+    write(nb, "script.py")
+    write(nb, "notebook.Rmd")
+    write(nb, "notebook.ipynb")
+    tmpdir.join("jupytext.toml").write("""notebook_extensions = ["ipynb", "Rmd"]""")
 
     cm = jupytext.TextFileContentsManager()
     cm.root_dir = str(tmpdir)
 
-    cm.notebook_extensions = "ipynb,Rmd"
     model = cm.get("notebook.ipynb")
     assert model["type"] == "notebook"
 
@@ -1682,28 +1804,23 @@ def test_multiple_pairing(tmpdir):
     assert model_py["last_modified"] <= model_md["last_modified"]
 
 
-@pytest.mark.parametrize("nb_file", list_notebooks("ipynb_py"))
-def test_filter_jupytext_version_information_416(nb_file, tmpdir):
-    tmp_py = str(tmpdir.join("notebook.py"))
-
+def test_filter_jupytext_version_information_416(python_notebook, tmpdir, cwd_tmpdir):
     cm = jupytext.TextFileContentsManager()
     cm.root_dir = str(tmpdir)
-    cm.default_notebook_metadata_filter = (
-        "-jupytext.text_representation.jupytext_version"
-    )
+    cm.notebook_metadata_filter = "-jupytext.text_representation.jupytext_version"
 
     # load notebook
-    notebook = jupytext.read(nb_file)
+    notebook = python_notebook
     notebook.metadata["jupytext_formats"] = "ipynb,py"
     model = notebook_model(notebook)
 
     # save to ipynb and py
     cm.save(model=model, path="notebook.ipynb")
 
-    assert os.path.isfile(tmp_py)
+    assert os.path.isfile("notebook.py")
 
     # read py file
-    with open(tmp_py) as fp:
+    with open("notebook.py") as fp:
         text = fp.read()
 
     assert "---" in text
@@ -1809,7 +1926,7 @@ def test_jupytext_jupyter_fs_metamanager(tmpdir):
 
 def test_config_jupytext_jupyter_fs_meta_manager(tmpdir):
     """Test the configuration of Jupytext with a fs manager"""
-    tmpdir.join("jupytext.toml").write('default_jupytext_formats = "ipynb,py"')
+    tmpdir.join("jupytext.toml").write('formats = "ipynb,py"')
     cm = fs_meta_manager(tmpdir)
     # the hash that corresponds to the osfs
     osfs = [h for h in cm._managers if h != ""][0]
